@@ -27,10 +27,10 @@ class SSHFileAdaptor(object):
         result = urlparse.urlparse(service_url)
         self.host = result.hostname
         self.path = result.path        
-	self.user = result.username
+        self.user = result.username
         
         # initialize ssh client
-	logger.debug("SSH: connect to: %s"%self.host)
+        logger.debug("SSH: connect to: %s"%self.host)
         self.__client = paramiko.SSHClient()
         self.__client.load_system_host_keys()
         self.__client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
@@ -235,7 +235,7 @@ class SSHFileAdaptor(object):
             else:
                 return False
         except:
-            logger.error("Directory not found: %s"%path)
+            logger.debug("Directory not found: %s"%path)
         sftp.close()
         client.close()
         return False
@@ -253,10 +253,14 @@ class SSHFileAdaptor(object):
         result = urlparse.urlparse(source_url)
         source_host = result.netloc
         source_path = result.path
+        if source_host==None or source_host=="":
+            source_host="localhost"
 
         result = urlparse.urlparse(target_url)
         target_host = result.netloc
         target_path = result.path
+        if target_host==None or target_host=="":
+            target_host="localhost"
 
         cmd = "scp -r %s:%s %s:%s"%(source_host, source_path, target_host, target_path)
         rc = os.system(cmd)
